@@ -6,7 +6,10 @@ from datetime import datetime
 from typing import Any, Dict, List, Text, Tuple
 
 from prettytable import PrettyTable
-from tqdm import tqdm
+from rich.console import Console
+from rich.progress import track
+from rich.table import Table
+from simple_term_menu import TerminalMenu
 
 from neuralspace.apis import get_async_http_session
 from neuralspace.constants import (
@@ -35,10 +38,10 @@ from neuralspace.constants import (
     MODELS,
     N_REPLICAS,
     NER_METRICS,
+    NO,
     NUMBER_OF_EXAMPLES,
     NUMBER_OF_INTENTS,
     NUMBER_OF_MODELS,
-    OUTPUT,
     PAGE_NUMBER,
     PAGE_SIZE,
     PREPARED,
@@ -52,6 +55,7 @@ from neuralspace.constants import (
     TRAINING_STATUS,
     TRAINING_TIME,
     TYPE,
+    YES,
     neuralspace_url,
 )
 from neuralspace.nlu.constants import (
@@ -72,6 +76,7 @@ from neuralspace.nlu.constants import (
 from neuralspace.utils import get_auth_token, is_success_status
 
 logger = logging.getLogger(__name__)
+console = Console()
 
 
 async def get_languages() -> Dict[Text, Any]:
@@ -93,11 +98,13 @@ async def get_languages() -> Dict[Text, Any]:
 
 
 async def create_project(project_name: Text, languages: List[Text]) -> Dict[Text, Any]:
-    logger.info(
-        f"Creating a project called {project_name} in languages: {', '.join(languages)}"
+    console.print(
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Creating a project called "
+        f"{project_name} in languages: {', '.join(languages)}!"
     )
     payload = {PROJECT_NAME: project_name, LANGUAGE: languages}
     HEADERS = copy(COMMON_HEADERS)
+    table = Table()
     HEADERS[AUTHORIZATION] = get_auth_token()
     async with get_async_http_session().post(
         url=f"{neuralspace_url()}/{CREATE_PROJECT_URL}",
@@ -106,11 +113,42 @@ async def create_project(project_name: Text, languages: List[Text]) -> Dict[Text
     ) as response:
         json_response = await response.json(encoding="utf-8")
         if is_success_status(response.status):
-            logger.info("Successfully created project")
-            logger.info(f"Project details: \n {json.dumps(json_response, indent=4)}")
+            console.print(
+                "> [deep_sky_blue2]INFO[/deep_sky_blue2]"
+                " 🗝 Retrieving credentials from config..."
+            )
+            console.print(
+                "> [deep_sky_blue2]INFO[/deep_sky_blue2] "
+                "✅ Successfully created project!"
+            )
+            console.print(
+                "> [deep_sky_blue2]INFO[/deep_sky_blue2] "
+                "Here 💁 is your project information..."
+            )
+            table.add_column("Name")
+            table.add_column("Language")
+            table.add_column("App Type")
+            table.add_column("Project Id", style="green")
+            language_to_write = ""
+            for i, language in enumerate(json_response[DATA]["language"]):
+                if i == len(json_response[DATA]["language"]) - 1:
+                    language_to_write += language
+                else:
+                    language_to_write += language + ", "
+            table.add_row(
+                json_response[DATA]["projectName"],
+                language_to_write,
+                json_response[DATA]["appType"],
+                json_response[DATA]["projectId"],
+            )
+            console.print(table)
+            console.print(
+                "⏩ Upload data to your project using this command:"
+                " [dark_orange3]neuralspace nlu upload-dataset[/dark_orange3]"
+            )
         else:
-            logger.error("Failed to create project")
-            logger.error(f"Platform response: \n {json.dumps(json_response, indent=4)}")
+            console.print("> [red]ERROR[/red] Failed ❌  to create project")
+            console.print(f"> 😔[red]{json_response[DATA]['error']}[/red]")
     return json_response
 
 
@@ -337,11 +375,17 @@ async def upload_dataset(
 ) -> List[Dict[Text, Any]]:
     responses = []
     error_examples = []
-    logger.info(
-        f"Uploading {len(nlu_data) - skip_first} examples for project {project_id} and language {language}"
+    console.print(
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Uploading {len(nlu_data) - skip_first} "
+        f"examples for project {project_id} and language {language}"
     )
-    logger.info(f"Skipping first {skip_first} examples")
-    for chunk_id, example in tqdm(enumerate(nlu_data[skip_first:])):
+    console.print(
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Skipping first {skip_first} examples"
+    )
+    for chunk_id, example in track(
+        enumerate(nlu_data[skip_first:]),
+        total=len(nlu_data[skip_first:]),
+    ):
         batch = {PROJECT_ID: project_id, LANGUAGE: language, EXAMPLE: example}
         HEADERS = copy(COMMON_HEADERS)
         HEADERS[AUTHORIZATION] = get_auth_token()
@@ -383,34 +427,39 @@ async def wait_till_training_completes(
         }
         HEADERS = copy(COMMON_HEADERS)
         HEADERS[AUTHORIZATION] = get_auth_token()
-        logger.info(f"Waiting for training job to get done for model id: {model_id}")
-        while True:
-            async with get_async_http_session().get(
-                url=f"{neuralspace_url()}/{SINGLE_MODEL_DETAILS_URL}",
-                params=payload,
-                headers=HEADERS,
-            ) as response:
-                json_response = await response.json(encoding="utf-8")
-                if is_success_status(response.status):
-                    logger.info(
-                        f"Current Status: {json_response[DATA][TRAINING_STATUS]}"
-                    )
-                    if (
-                        json_response[DATA][TRAINING_STATUS] == COMPLETED
-                        or json_response[DATA][TRAINING_STATUS] == FAILED
-                        or json_response[DATA][TRAINING_STATUS] == TIMED_OUT
-                        or json_response[DATA][TRAINING_STATUS] == DEAD
-                    ):
+        console.print(
+            f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Waiting for training job to "
+            f"get done for model id: {model_id}"
+        )
+        current_status = ""
+        with console.status("...") as status:
+            while True:
+                async with get_async_http_session().get(
+                    url=f"{neuralspace_url()}/{SINGLE_MODEL_DETAILS_URL}",
+                    params=payload,
+                    headers=HEADERS,
+                ) as response:
+                    json_response = await response.json(encoding="utf-8")
+                    if is_success_status(response.status):
+                        current_status = json_response[DATA][TRAINING_STATUS]
+                        if (
+                            json_response[DATA][TRAINING_STATUS] == COMPLETED
+                            or json_response[DATA][TRAINING_STATUS] == FAILED
+                            or json_response[DATA][TRAINING_STATUS] == TIMED_OUT
+                            or json_response[DATA][TRAINING_STATUS] == DEAD
+                        ):
+                            break
+                    else:
+                        console.print(
+                            "> [red]ERROR[/red] Failed to fetch model details"
+                        )
+                        console.print(
+                            f"> [red]ERROR[/red] Platform Response: \n {json.dumps(json_response, indent=4)}"
+                        )
                         break
-                    logger.info(f"Waiting for {wait_interval} seconds")
-
-                else:
-                    logger.error("Failed to fetch model details")
-                    logger.error(
-                        f"Platform Response: \n {json.dumps(json_response, indent=4)}"
-                    )
-                    break
-            await sleep(wait_interval)
+                    status.update(f"Model is {current_status} 🧍")
+                    await sleep(wait_interval)
+                    status.update(f"Model is {current_status} 🏋")
     return json_response
 
 
@@ -421,32 +470,41 @@ async def train_model(
     wait: bool = True,
     wait_time: int = 1,
 ) -> Tuple[Dict[Text, Any], Dict[Text, Any]]:
-    logger.info(
-        f"Queuing training job for: Project ID: {project_id}; Language: {language}; "
-        f"Model Name: {model_name}"
+    console.print(
+        f"> [deep_sky_blue2]INFO[/deep_sky_blue2] Queuing training job for: "
+        f"Project ID: {project_id}; Language: {language}; "
+        f"[deep_sky_blue2]INFO[/deep_sky_blue2] Model Name: {model_name}"
     )
     payload = {PROJECT_ID: project_id, LANGUAGE: language, MODEL_NAME: model_name}
     HEADERS = copy(COMMON_HEADERS)
     HEADERS[AUTHORIZATION] = get_auth_token()
 
-    async with get_async_http_session().post(
-        url=f"{neuralspace_url()}/{TRAIN_MODEL_URL}",
-        data=json.dumps(payload),
-        headers=HEADERS,
-    ) as response:
-        json_response = await response.json(encoding="utf-8")
-        if is_success_status(response.status):
-            logger.info("Training job queued successfully")
-            logger.info(f"Platform Response: \n{json_response}")
-            model_id = json_response[DATA]["model_id"]
-            last_model_status = await wait_till_training_completes(
-                model_id, wait, wait_time
-            )
-        else:
-            logger.error("Failed to queue training job")
-            logger.error(f"Platform response: \n {json.dumps(json_response, indent=4)}")
-            last_model_status = None
-    return json_response, last_model_status
+    console.print("[red]Do you really want to train the model: [/red]")
+    options = [YES, NO]
+    terminal_menu = TerminalMenu(options)
+    menu_entry_index = terminal_menu.show()
+    if options[menu_entry_index] == YES:
+        async with get_async_http_session().post(
+            url=f"{neuralspace_url()}/{TRAIN_MODEL_URL}",
+            data=json.dumps(payload),
+            headers=HEADERS,
+        ) as response:
+            json_response = await response.json(encoding="utf-8")
+            if is_success_status(response.status):
+                console.print(
+                    "> [deep_sky_blue2]INFO[/deep_sky_blue2] Training job queued successfully"
+                )
+                model_id = json_response[DATA]["model_id"]
+                last_model_status = await wait_till_training_completes(
+                    model_id, wait, wait_time
+                )
+            else:
+                console.print("> [red]ERROR[/red] Failed to queue training job")
+                console.print(f"> [red]ERROR[/red] {json_response['message']}")
+                last_model_status = None
+        return json_response, last_model_status
+    else:
+        console.print("Please read through and train the model again")
 
 
 async def delete_models(model_id: Text) -> Dict[Text, Any]:
@@ -500,13 +558,13 @@ def print_nlu_response(nlu_response: Dict[Text, Any], response_time: float):
     ]
     table.add_row(
         [
-            nlu_response[DATA][OUTPUT]["result"]["text"][:30] + "[...]",
-            nlu_response[DATA][OUTPUT]["result"]["intent"]["name"],
-            nlu_response[DATA][OUTPUT]["result"]["intent"]["confidence"],
+            nlu_response[DATA]["text"][:30] + "[...]",
+            nlu_response[DATA]["intent"]["name"],
+            nlu_response[DATA]["intent"]["confidence"],
             "; ".join(
                 [
                     f"{e['entity']}|{e['value']}|{e['start']}:{e['end']} "
-                    for e in nlu_response[DATA][OUTPUT]["result"]["entities"]
+                    for e in nlu_response[DATA]["entities"]
                 ]
             ),
             response_time / 1000,
@@ -516,7 +574,7 @@ def print_nlu_response(nlu_response: Dict[Text, Any], response_time: float):
     intent_ranking_table = PrettyTable()
     intent_ranking_table.field_names = ["Intent", "Confidence"]
 
-    for row in nlu_response[DATA][OUTPUT]["result"]["intent_ranking"]:
+    for row in nlu_response[DATA]["intent_ranking"]:
         intent_ranking_table.add_row(
             [
                 row["name"],
